@@ -1,7 +1,7 @@
 #############################################################################
 #   $Author: markus $
-#     $Date: 2008-11-04 23:58:40 +0100 (Tue, 04 Nov 2008) $
-# $Revision: 1154 $
+#     $Date: 2008-11-23 01:38:40 +0100 (Sun, 23 Nov 2008) $
+# $Revision: 1238 $
 #############################################################################
 
 package LaTeX::Table::Themes::Booktabs;
@@ -10,17 +10,24 @@ use Moose;
 with 'LaTeX::Table::Themes::ThemeI';
 
 use version;
-our ($VERSION) = '$Revision: 1154 $' =~ m{ \$Revision: \s+ (\S+) }xms;
+our ($VERSION) = '$Revision: 1238 $' =~ m{ \$Revision: \s+ (\S+) }xms;
 
 sub _definition {
-    return { Zurich =>
-     {
-        'HEADER_FONT_STYLE' => 'bf',
-        'HEADER_CENTERED'   => 1,
-        'VERTICAL_LINES'    => [ 0, 0, 0 ],
-        'HORIZONTAL_LINES'  => [ 1, 1, 0 ],
-        'BOOKTABS'          => 1,
-    }};
+    my $themes = {
+        'Zurich' => {
+            'HEADER_FONT_STYLE' => 'bf',
+            'HEADER_CENTERED'   => 1,
+            'VERTICAL_LINES'    => [ 0, 0, 0 ],
+            'HORIZONTAL_LINES'  => [ 1, 1, 0 ],
+            'BOOKTABS'          => 1,
+        },
+        'Meyrin' => {
+            'VERTICAL_LINES'   => [ 0, 0, 0 ],
+            'HORIZONTAL_LINES' => [ 1, 1, 0 ],
+            'BOOKTABS'         => 1,
+        },
+    };
+    return $themes;
 }
 
 1;
@@ -34,7 +41,8 @@ LaTeX::Table::Themes::Booktabs - Publication quality tables.
 
 This module provides following themes:
 
-  Zurich
+  Zurich   # header centered and in bold font
+  Meyrin   # as described in the booktabs documentation
 
 =head1 REQUIRES
 
